@@ -11,7 +11,6 @@ These are additional urls used by the Sentry-provided web server
 import os
 
 from sentry.web.urls import urlpatterns as web_urlpatterns
-from sentry.web.frontend import generic
 from django.conf.urls.defaults import patterns, url, include
 from django.contrib import admin
 from django.views.defaults import page_not_found
@@ -41,7 +40,4 @@ def handler500(request):
 urlpatterns = patterns('',
     url(r'^i18n/', include('django.conf.urls.i18n')),
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^_admin_media/(?P<path>.*)$', generic.static_media,
-        kwargs={'root': admin_media_dir},
-        name='admin-media'),
 ) + web_urlpatterns
