@@ -2,7 +2,7 @@
 sentry.manager
 ~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -31,14 +31,14 @@ from django.utils.encoding import force_unicode
 from raven.utils.encoding import to_string
 from sentry import app
 from sentry.conf import settings
-from sentry.constants import STATUS_RESOLVED, STATUS_UNRESOLVED
+from sentry.constants import STATUS_RESOLVED, STATUS_UNRESOLVED, MINUTE_NORMALIZATION
 from sentry.processors.base import send_group_processors
 from sentry.signals import regression_signal
 from sentry.tasks.index import index_event
 from sentry.tasks.fetch_source import fetch_javascript_source
-from sentry.utils.cache import cache, Lock
-from sentry.utils.dates import get_sql_date_trunc
-from sentry.utils.db import get_db_engine, has_charts
+from sentry.utils.cache import cache, memoize, Lock
+from sentry.utils.dates import get_sql_date_trunc, normalize_datetime
+from sentry.utils.db import get_db_engine, has_charts, attach_foreignkey
 from sentry.utils.models import create_or_update, make_key
 from sentry.utils.queue import maybe_delay
 
@@ -311,7 +311,7 @@ class ChartMixin(object):
         # the last interval is not accurate, so we exclude it
         # TODO: it'd be ideal to normalize the last datapoint so that we can include it
         # and not have ~inaccurate data for up to MINUTE_NORMALIZATION
-        today -= datetime.timedelta(minutes=settings.MINUTE_NORMALIZATION)
+        today -= datetime.timedelta(minutes=MINUTE_NORMALIZATION)
 
         if max_days >= 30:
             g_type = 'date'
@@ -328,7 +328,7 @@ class ChartMixin(object):
         else:
             g_type = 'minute'
             d_type = 'minutes'
-            modifier = settings.MINUTE_NORMALIZATION
+            modifier = MINUTE_NORMALIZATION
             points = max_days * 24 * (60 / modifier)
 
         min_date = today - datetime.timedelta(days=max_days)
@@ -484,7 +484,7 @@ class GroupManager(BaseManager, ChartMixin):
 
         if settings.SCRAPE_JAVASCRIPT_CONTEXT and event.platform == 'javascript' and not is_sample:
             try:
-                maybe_delay(fetch_javascript_source, event)
+                maybe_delay(fetch_javascript_source, event, expires=900)
             except Exception, e:
                 transaction.rollback_unless_managed(using=group._state.db)
                 logger.exception(u'Error fetching javascript source: %s', e)
@@ -533,12 +533,13 @@ class GroupManager(BaseManager, ChartMixin):
             if message:
                 extra['message'] = message
 
-            if group.status == STATUS_RESOLVED:
+            if group.status == STATUS_RESOLVED or group.is_over_resolve_age():
                 # Makin things atomic
                 is_new = bool(self.filter(
                     id=group.id,
                 ).exclude(
                     status=STATUS_UNRESOLVED,
+                    active_at__gte=date,
                 ).update(active_at=date, status=STATUS_UNRESOLVED))
 
                 group.active_at = date
@@ -570,11 +571,7 @@ class GroupManager(BaseManager, ChartMixin):
             is_sample = True
 
         # Rounded down to the nearest interval
-        if settings.MINUTE_NORMALIZATION:
-            minutes = (date.minute - (date.minute % settings.MINUTE_NORMALIZATION))
-        else:
-            minutes = date.minute
-        normalized_datetime = date.replace(second=0, microsecond=0, minute=minutes)
+        normalized_datetime = normalize_datetime(date)
 
         app.buffer.incr(GroupCountByMinute, update_kwargs, {
             'group': group,
@@ -651,7 +648,7 @@ class GroupManager(BaseManager, ChartMixin):
         })
 
     def add_tags(self, group, tags):
-        from sentry.models import FilterValue, FilterKey, GroupTag
+        from sentry.models import FilterValue, GroupTag
 
         project = group.project
         date = group.last_seen
@@ -664,17 +661,15 @@ class GroupManager(BaseManager, ChartMixin):
             if len(value) > MAX_TAG_LENGTH:
                 continue
 
-            # TODO: FilterKey and FilterValue queries should be create's under a try/except
-            FilterKey.objects.get_or_create(
-                project=project,
-                key=key,
-            )
-
-            FilterValue.objects.get_or_create(
-                project=project,
-                key=key,
-                value=value,
-            )
+            app.buffer.incr(FilterValue, {
+                'times_seen': 1,
+            }, {
+                'project': project,
+                'key': key,
+                'value': value,
+            }, {
+                'last_seen': date,
+            })
 
             app.buffer.incr(GroupTag, {
                 'times_seen': 1,
@@ -690,69 +685,74 @@ class GroupManager(BaseManager, ChartMixin):
     def get_by_natural_key(self, project, logger, culprit, checksum):
         return self.get(project=project, logger=logger, view=culprit, checksum=checksum)
 
+    @memoize
+    def model_fields_clause(self):
+        return ', '.join('sentry_groupedmessage."%s"' % (f.column,) for f in self.model._meta.fields)
+
     def get_accelerated(self, project_ids, queryset=None, minutes=15):
-        # mintues should
-        from sentry.models import GroupCountByMinute
-        mcbm_tbl = GroupCountByMinute._meta.db_table
+        if not project_ids:
+            return self.none()
+
         if queryset is None:
-            queryset = self
+            queryset = self.filter(
+                project__in=project_ids,
+                status=STATUS_UNRESOLVED,
+            )
+        else:
+            queryset = queryset._clone()
+            queryset.query.select_related = False
 
-        queryset = queryset._clone()
-        queryset.query.select_related = False
+        normalization = float(MINUTE_NORMALIZATION)
 
-        normalization = float(settings.MINUTE_NORMALIZATION)
         assert minutes >= normalization
 
+        intervals = 8
+
         engine = get_db_engine(queryset.db)
         # We technically only support mysql and postgresql, since there seems to be no standard
         # way to get the epoch from a datetime/interval
         if engine.startswith('mysql'):
             minute_clause = "interval %s minute"
-            epoch_clause = "unix_timestamp(utc_timestamp()) - unix_timestamp(%(mcbm_tbl)s.date)"
+            epoch_clause = "unix_timestamp(utc_timestamp()) - unix_timestamp(mcbm.date)"
             now_clause = 'utc_timestamp()'
         else:
             minute_clause = "interval '%s minutes'"
-            epoch_clause = "extract(epoch from now()) - extract(epoch from %(mcbm_tbl)s.date)"
+            epoch_clause = "extract(epoch from now()) - extract(epoch from mcbm.date)"
             now_clause = 'now()'
 
-        epoch_clause = epoch_clause % dict(mcbm_tbl=mcbm_tbl)
-
-        queryset = queryset.annotate(x=Sum('groupcountbyminute__times_seen')).order_by('id')
-
         sql, params = queryset.query.get_compiler(queryset.db).as_sql()
         before_select, after_select = str(sql).split('SELECT ', 1)
-        before_where, after_where = after_select.split(' WHERE ', 1)
-        before_group, after_group = after_where.split(' GROUP BY ', 1)
+        after_where = after_select.split(' WHERE ', 1)[1]
 
         # Ensure we remove any ordering clause
-        after_group = after_group.split(' ORDER BY ')[0]
+        after_where = after_where.split(' ORDER BY ')[0]
 
-        # TODO: adding project_id to sort clause on left join helps query in many cases
         query = """
-        SELECT (SUM(%(mcbm_tbl)s.times_seen) * (%(norm)f / (%(epoch_clause)s / 60)) + 1.0) / (COALESCE(z.rate, 0) + 1.0) as sort_value,
-               (COALESCE(z.rate, 0) + 1.0) as prev_rate,
-               %(before_where)s
-        LEFT JOIN (SELECT a.group_id, SUM(a.times_seen) / COUNT(a.times_seen) / %(norm)f as rate
-            FROM %(mcbm_tbl)s as a
+        SELECT ((mcbm.times_seen + 1) / ((%(epoch_clause)s) / 60)) / (COALESCE(z.rate, 0) + 1) as sort_value,
+               %(fields)s
+        FROM sentry_groupedmessage
+        INNER JOIN sentry_messagecountbyminute as mcbm
+            ON (sentry_groupedmessage.id = mcbm.group_id)
+        LEFT JOIN (SELECT a.group_id, (SUM(a.times_seen)) / COUNT(a.times_seen) / %(norm)f as rate
+            FROM sentry_messagecountbyminute as a
             WHERE a.date >=  %(now)s - %(max_time)s
             AND a.date < %(now)s - %(min_time)s
             AND a.project_id IN (%(project_ids)s)
             GROUP BY a.group_id) as z
-        ON z.group_id = %(mcbm_tbl)s.group_id
-        WHERE %(mcbm_tbl)s.date >= %(now)s - %(min_time)s
-        AND %(mcbm_tbl)s.date < %(now)s - %(offset_time)s
-        AND %(before_group)s
-        GROUP BY prev_rate, %(mcbm_tbl)s.date, %(after_group)s
-        HAVING SUM(%(mcbm_tbl)s.times_seen) > 0
+        ON z.group_id = mcbm.group_id
+        WHERE mcbm.date >= %(now)s - %(min_time)s
+        AND mcbm.date < %(now)s - %(offset_time)s
+        AND mcbm.times_seen > 0
+        AND ((mcbm.times_seen + 1) / ((%(epoch_clause)s) / 60)) > (COALESCE(z.rate, 0) + 1)
+        AND %(after_where)s
+        GROUP BY z.rate, mcbm.times_seen, mcbm.date, %(fields)s
         ORDER BY sort_value DESC
         """ % dict(
-            mcbm_tbl=mcbm_tbl,
-            before_where=before_where,
-            before_group=before_group,
-            after_group=after_group,
+            fields=self.model_fields_clause,
+            after_where=after_where,
             offset_time=minute_clause % (1,),
             min_time=minute_clause % (minutes + 1,),
-            max_time=minute_clause % (minutes * (60 / normalization),),
+            max_time=minute_clause % (minutes * intervals + 1,),
             norm=normalization,
             epoch_clause=epoch_clause,
             now=now_clause,
@@ -779,7 +779,45 @@ class RawQuerySet(object):
 
 
 class ProjectManager(BaseManager, ChartMixin):
-    pass
+    def get_for_user(self, user=None, access=None, hidden=False, team=None):
+        """
+        Returns a SortedDict of all projects a user has some level of access to.
+        """
+        from sentry.models import Team
+
+        if not (user and user.is_authenticated()):
+            return []
+
+        # TODO: the result of this function should be cached
+        is_authenticated = (user and user.is_authenticated())
+
+        base_qs = self
+        if not hidden:
+            base_qs = base_qs.filter(status=0)
+        if team:
+            base_qs = base_qs.filter(team=team)
+
+        if team and user.is_superuser:
+            projects = set(base_qs)
+        else:
+            if not settings.PUBLIC:
+                # If the user is authenticated, include their memberships
+                teams = Team.objects.get_for_user(user, access).values()
+                if not teams:
+                    return []
+                if team and team not in teams:
+                    return []
+                elif not team:
+                    base_qs = base_qs.filter(team__in=teams)
+
+            projects = set(base_qs)
+
+            if is_authenticated:
+                projects |= set(base_qs.filter(accessgroup__members=user))
+
+        attach_foreignkey(projects, self.model.team)
+
+        return sorted(projects, key=lambda x: x.name)
 
 
 class MetaManager(BaseManager):
