@@ -2,7 +2,7 @@
 sentry.plugins.sentry_mail.models
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import sentry
@@ -62,20 +62,9 @@ class MailProcessor(NotificationPlugin):
     project_default_enabled = True
     project_conf_form = MailConfigurationForm
 
-    def __init__(self, min_level=NOTSET, include_loggers=NOTSET, exclude_loggers=NOTSET,
-                 send_to=None, send_to_members=NOTSET, *args, **kwargs):
-
+    def __init__(self, min_level=0, include_loggers=None, exclude_loggers=None,
+                 send_to=None, send_to_members=True, *args, **kwargs):
         super(MailProcessor, self).__init__(*args, **kwargs)
-
-        if min_level is NOTSET:
-            min_level = settings.MAIL_LEVEL
-        if include_loggers is NOTSET:
-            include_loggers = settings.MAIL_INCLUDE_LOGGERS
-        if exclude_loggers is NOTSET:
-            exclude_loggers = settings.MAIL_EXCLUDE_LOGGERS
-        if send_to_members is NOTSET:
-            send_to_members = True
-
         self.min_level = min_level
         self.include_loggers = include_loggers
         self.exclude_loggers = exclude_loggers
@@ -197,6 +186,8 @@ class MailProcessor(NotificationPlugin):
             'event': event,
             'link': link,
             'interfaces': interface_list,
+            'settings_link': '%s%s' % (settings.URL_PREFIX,
+                reverse('sentry-account-settings-notifications')),
         })).run()
 
     def get_option(self, key, *args, **kwargs):
