@@ -1,7 +1,9 @@
 (function(app, Backbone){
     "use strict";
 
-    app.Group = Backbone.Model.extend({
+    app.models = {};
+
+    app.models.Group = Backbone.Model.extend({
 
         defaults: {
             tags: [],
@@ -9,6 +11,15 @@
             isBookmarked: false,
             historicalData: []
         }
+
     });
 
+    app.models.User = Backbone.Model.extend({
+
+        defaults: {
+        }
+
+    });
+
+
 }(app, Backbone));
