@@ -2,16 +2,22 @@
 sentry.utils.http
 ~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import urllib
-from urlparse import urlparse
+from urlparse import urlparse, urljoin
 
 from sentry.conf import settings
 from sentry.plugins.helpers import get_option
 
 
+def absolute_uri(url=None):
+    if not url:
+        return settings.URL_PREFIX
+    return urljoin(settings.URL_PREFIX, url)
+
+
 def safe_urlencode(params, doseq=0):
     """
     UTF-8-safe version of safe_urlencode
