@@ -2,18 +2,17 @@
 sentry.web.views
 ~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import datetime
 import logging
 from functools import wraps
 
-from django.contrib.auth.models import AnonymousUser
+from django.contrib.auth.models import AnonymousUser, User
 from django.core.urlresolvers import reverse
-from django.db.models import Sum
-from django.http import HttpResponse, \
-  HttpResponseForbidden, HttpResponseRedirect
+from django.db.models import Sum, Q
+from django.http import HttpResponse, HttpResponseForbidden, HttpResponseRedirect
 from django.utils import timezone
 from django.views.decorators.cache import never_cache
 from django.views.decorators.csrf import csrf_exempt
@@ -36,7 +35,7 @@ from sentry.utils.javascript import to_json
 from sentry.utils.http import is_valid_origin, get_origins
 from sentry.web.decorators import has_access
 from sentry.web.frontend.groups import _get_group_list
-from sentry.web.helpers import render_to_response, get_project_list
+from sentry.web.helpers import render_to_response
 
 error_logger = logging.getLogger('sentry.errors.api.http')
 logger = logging.getLogger('sentry.api.http')
@@ -374,6 +373,28 @@ def make_group_private(request, team, project, group_id):
     return to_json(group, request)
 
 
+@csrf_exempt
+@has_access(MEMBER_USER)
+@never_cache
+@api
+def resolve_group(request, team, project, group_id):
+    try:
+        group = Group.objects.get(pk=group_id)
+    except Group.DoesNotExist:
+        return HttpResponseForbidden()
+
+    happened = group.update(status=STATUS_RESOLVED)
+    if happened:
+        Activity.objects.create(
+            project=project,
+            group=group,
+            type=Activity.SET_RESOLVED,
+            user=request.user,
+        )
+
+    return to_json(group, request)
+
+
 @csrf_exempt
 @has_access(MEMBER_USER)
 @never_cache
@@ -400,7 +421,7 @@ def mute_group(request, team, project, group_id):
 @has_access(MEMBER_USER)
 @never_cache
 @api
-def unmute_group(request, team, project, group_id):
+def unresolve_group(request, team, project, group_id):
     try:
         group = Group.objects.get(pk=group_id)
     except Group.DoesNotExist:
@@ -519,7 +540,7 @@ def chart(request, team=None, project=None):
 
         data = cache.get(cache_key)
         if data is None:
-            project_list = get_project_list(request.user).values()
+            project_list = Project.objects.get_for_user(request.user)
             data = Project.objects.get_chart_data_for_group(project_list, max_days=days)
             cache.set(cache_key, data, 300)
 
@@ -535,20 +556,20 @@ def get_group_trends(request, team=None, project=None):
     minutes = int(request.REQUEST.get('minutes', 15))
     limit = min(100, int(request.REQUEST.get('limit', 10)))
 
-    if team:
-        project_dict = dict((p.id, p) for p in Project.objects.filter(team=team))
-    elif project:
-        project_dict = {project.id: project}
+    if not team and project:
+        project_list = [project]
     else:
-        project_dict = get_project_list(request.user)
+        project_list = Project.objects.get_for_user(request.user, team=team)
+
+    project_dict = dict((p.id, p) for p in project_list)
 
     base_qs = Group.objects.filter(
-        project__in=project_dict.keys(),
+        project__in=project_list,
         status=0,
     )
 
     if has_trending():
-        group_list = list(Group.objects.get_accelerated(project_dict.keys(), base_qs, minutes=(
+        group_list = list(Group.objects.get_accelerated(project_dict, base_qs, minutes=(
             minutes
         ))[:limit])
     else:
@@ -578,12 +599,12 @@ def get_new_groups(request, team=None, project=None):
     minutes = int(request.REQUEST.get('minutes', 15))
     limit = min(100, int(request.REQUEST.get('limit', 10)))
 
-    if team:
-        project_dict = dict((p.id, p) for p in Project.objects.filter(team=team))
-    elif project:
-        project_dict = {project.id: project}
+    if not team and project:
+        project_list = [project]
     else:
-        project_dict = get_project_list(request.user)
+        project_list = Project.objects.get_for_user(request.user, team=team)
+
+    project_dict = dict((p.id, p) for p in project_list)
 
     cutoff = datetime.timedelta(minutes=minutes)
     cutoff_dt = timezone.now() - cutoff
@@ -612,21 +633,24 @@ def get_resolved_groups(request, team=None, project=None):
     minutes = int(request.REQUEST.get('minutes', 15))
     limit = min(100, int(request.REQUEST.get('limit', 10)))
 
-    if team:
-        project_list = list(Project.objects.filter(team=team))
-    elif project:
+    if not team and project:
         project_list = [project]
     else:
-        project_list = get_project_list(request.user).values()
+        project_list = Project.objects.get_for_user(request.user, team=team)
+
+    project_dict = dict((p.id, p) for p in project_list)
 
     cutoff = datetime.timedelta(minutes=minutes)
     cutoff_dt = timezone.now() - cutoff
 
-    group_list = Group.objects.filter(
+    group_list = list(Group.objects.filter(
         project__in=project_list,
         status=STATUS_RESOLVED,
         resolved_at__gte=cutoff_dt,
-    ).select_related('project').order_by('-score')[:limit]
+    ).order_by('-score')[:limit])
+
+    for group in group_list:
+        group._project_cache = project_dict.get(group.project_id)
 
     data = to_json(group_list, request)
 
@@ -639,13 +663,13 @@ def get_resolved_groups(request, team=None, project=None):
 @never_cache
 @csrf_exempt
 @has_access
-def get_stats(request, project=None):
+def get_stats(request, team=None, project=None):
     minutes = int(request.REQUEST.get('minutes', 15))
 
-    if project:
+    if not team and project:
         project_list = [project]
     else:
-        project_list = get_project_list(request.user).values()
+        project_list = Project.objects.get_for_user(request.user, team=team)
 
     cutoff = datetime.timedelta(minutes=minutes)
     cutoff_dt = timezone.now() - cutoff
@@ -689,6 +713,49 @@ def search_tags(request, team, project):
 
     response = HttpResponse(json.dumps({
         'results': results,
+        'query': query,
+    }))
+    response['Content-Type'] = 'application/json'
+
+    return response
+
+
+@never_cache
+@csrf_exempt
+@has_access
+def search_users(request, team):
+    limit = min(100, int(request.GET.get('limit', 10)))
+    query = request.GET['query']
+
+    results = list(User.objects.filter(
+        Q(email__istartswith=query) | Q(first_name__istartswith=query) | Q(username__istartswith=query),
+    ).filter(
+        Q(team_memberships=team) | Q(accessgroup__team=team),
+    ).distinct().order_by('first_name', 'email').values('id', 'username', 'first_name', 'email')[:limit])
+
+    response = HttpResponse(json.dumps({
+        'results': results,
+        'query': query,
+    }))
+    response['Content-Type'] = 'application/json'
+
+    return response
+
+
+@never_cache
+@csrf_exempt
+@has_access
+def search_projects(request, team):
+    limit = min(100, int(request.GET.get('limit', 10)))
+    query = request.GET['query']
+
+    results = list(Project.objects.filter(
+        Q(name__istartswith=query) | Q(slug__istartswith=query),
+    ).filter(team=team).distinct().order_by('name', 'slug').values('id', 'name', 'slug')[:limit])
+
+    response = HttpResponse(json.dumps({
+        'results': results,
+        'query': query,
     }))
     response['Content-Type'] = 'application/json'
 
@@ -709,7 +776,7 @@ def crossdomain_xml(request, project_id):
     try:
         project = Project.objects.get_from_cache(**lookup)
     except Project.DoesNotExist:
-        return HttpResponse(status_code=404)
+        return HttpResponse(status=404)
 
     origin_list = get_origins(project)
     if origin_list == '*':
