@@ -2,7 +2,7 @@
 sentry.web.forms.projects
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 import itertools
@@ -13,8 +13,8 @@ from django.utils.translation import ugettext_lazy as _
 from sentry.constants import EMPTY_PASSWORD_VALUES
 from sentry.models import Project, ProjectOption
 from sentry.permissions import can_set_public_projects
-from sentry.web.forms.fields import RadioFieldRenderer, UserField, OriginsField, \
-  get_team_choices
+from sentry.web.forms.fields import (RadioFieldRenderer, UserField, OriginsField,
+    RangeField, get_team_choices)
 
 
 BLANK_CHOICE = [("", "")]
@@ -113,6 +113,8 @@ class EditProjectForm(BaseProjectForm):
     team = forms.TypedChoiceField(choices=(), coerce=int)
     origins = OriginsField(label=_('Allowed Domains'), required=False,
         help_text=_('Separate multiple entries with a newline.'))
+    resolve_age = RangeField(help_text=_('Treat an event as resolved if it hasn\'t been seen for this amount of time.'),
+        required=False, min_value=0, max_value=168, step_value=1)
 
     class Meta:
         fields = ('name', 'platform', 'public', 'team')
@@ -153,3 +155,23 @@ class EditProjectAdminForm(EditProjectForm):
     class Meta:
         fields = ('name', 'platform', 'public', 'team', 'owner', 'slug')
         model = Project
+
+
+class AlertSettingsForm(forms.Form):
+    active = forms.BooleanField(help_text=_('Enable notifications for this project. Users can override this within their personal settings'),
+        required=False)
+    event_age = RangeField(help_text=_('Notify the first time an event is seen after this amount of time.'),
+        required=False, min_value=0, max_value=168, step_value=1)
+
+
+class NotificationTagValuesForm(forms.Form):
+    values = forms.CharField(required=False)
+
+    def __init__(self, project, tag, *args, **kwargs):
+        self.project = project
+        self.tag = tag
+        super(NotificationTagValuesForm, self).__init__(*args, **kwargs)
+        self.fields['values'].label = self.tag
+
+    def clean_values(self):
+        return set(filter(bool, self.cleaned_data.get('values').split(',')))
