@@ -6,7 +6,7 @@ Contains views for the "Events" section of Sentry.
 
 TODO: Move all events.py views into here, and rename this file to events.
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 from __future__ import division
@@ -116,8 +116,6 @@ def _get_group_list(request, project):
         score_clause = SORT_CLAUSES.get(sort)
         filter_clause = SCORE_CLAUSES.get(sort)
 
-    event_list = event_list.select_related('project')
-
     # IMPORTANT: All filters must already be applied once we reach this point
 
     if sort == 'tottime':
@@ -154,21 +152,12 @@ def _get_group_list(request, project):
 
 
 def render_with_group_context(group, template, context, request=None, event=None):
-    activity = Activity.objects.filter(
-        group=group,
-    ).order_by('-datetime').select_related('user')
-    if event:
-        activity = activity.filter(Q(event__isnull=True) | Q(event=event))
-
-    activity = list(activity)
-
     context.update({
         'team': group.project.team,
         'project': group.project,
         'group': group,
         'can_admin_event': can_admin_group(request.user, group),
         'SECTION': 'events',
-        'activity': activity,
     })
 
     if event:
@@ -187,9 +176,13 @@ def render_with_group_context(group, template, context, request=None, event=None
             next_event = None
             prev_event = None
 
+        extra_data = event.data.get('extra', {})
+        if not isinstance(extra_data, dict):
+            extra_data = {}
+
         context.update({
             'event': event,
-            'json_data': event.data.get('extra', {}),
+            'json_data': extra_data,
             'version_data': event.data.get('modules', None),
             'next_event': next_event,
             'prev_event': prev_event,
@@ -345,7 +338,14 @@ def group(request, team, project, group):
     event = group.get_latest_event() or Event()
     event.group = group
 
-    context = {'page': 'details'}
+    activity = list(Activity.objects.filter(
+        group=group,
+    ).order_by('-datetime').select_related('user')[:10])
+
+    context = {
+        'page': 'details',
+        'activity': activity,
+    }
 
     if group_is_public(group, request.user):
         template = 'sentry/groups/public_details.html'
@@ -417,8 +417,15 @@ def group_event_list_json(request, team, project, group_id):
 def group_event_details(request, team, project, group, event_id):
     event = get_object_or_404(group.event_set, id=event_id)
 
+    activity = list(Activity.objects.filter(
+        group=group,
+    ).filter(
+        Q(event=event) | Q(event__isnull=True),
+    ).order_by('-datetime').select_related('user')[:10])
+
     return render_with_group_context(group, 'sentry/groups/details.html', {
         'page': 'details',
+        'activity': activity,
     }, request, event=event)
 
 
