@@ -14,17 +14,16 @@ from django.views.decorators.http import require_http_methods
 from django.utils.translation import ugettext_lazy as _
 
 from sentry.constants import MEMBER_OWNER
-from sentry.models import ProjectKey, Team, FilterKey
+from sentry.models import Project, ProjectKey, Team, FilterKey
 from sentry.permissions import (can_create_projects, can_remove_project, can_create_teams,
     can_add_project_key, can_remove_project_key)
 from sentry.plugins import plugins
-from sentry.plugins.helpers import set_option, get_option
 from sentry.web.decorators import login_required, has_access
 from sentry.web.forms.projects import (NewProjectForm, NewProjectAdminForm,
-    ProjectTagsForm, EditProjectForm, RemoveProjectForm, EditProjectAdminForm)
+    ProjectTagsForm, EditProjectForm, RemoveProjectForm, EditProjectAdminForm,
+    NotificationTagValuesForm)
 from sentry.web.forms.teams import NewTeamForm, SelectTeamForm
-from sentry.web.helpers import (render_to_response, get_project_list,
-    plugin_config)
+from sentry.web.helpers import render_to_response, plugin_config
 
 
 @login_required
@@ -110,7 +109,7 @@ def remove_project(request, team, project):
     if not can_remove_project(request.user, project):
         return HttpResponseRedirect(reverse('sentry'))
 
-    project_list = filter(lambda x: x != project, get_project_list(request.user).itervalues())
+    project_list = filter(lambda x: x != project, Project.objects.get_for_user(request.user))
 
     form = RemoveProjectForm(request.user, project_list, request.POST or None)
 
@@ -158,14 +157,15 @@ def manage_project(request, team, project):
         form_cls = EditProjectForm
 
     form = form_cls(request, team_list, request.POST or None, instance=project, initial={
-        'origins': '\n'.join(get_option('sentry:origins', project) or []),
+        'origins': '\n'.join(project.get_option('sentry:origins', None) or []),
         'owner': project.owner,
+        'resolve_age': int(project.get_option('sentry:resolve_age', 0)),
     })
 
     if form.is_valid():
         project = form.save()
-        set_option('sentry:origins', form.cleaned_data.get('origins') or [], project)
-
+        project.update_option('sentry:origins', form.cleaned_data.get('origins') or [])
+        project.update_option('sentry:resolve_age', form.cleaned_data.get('resolve_age'))
         messages.add_message(request, messages.SUCCESS,
             _('Changes to your project were saved.'))
 
@@ -275,6 +275,48 @@ def manage_project_tags(request, team, project):
     return render_to_response('sentry/projects/manage_tags.html', context, request)
 
 
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def notification_settings(request, team, project):
+    initial = project.get_option('notifcation:tags', {})
+
+    tag_forms = []
+    for tag in FilterKey.objects.all_keys(project):
+        tag_forms.append(NotificationTagValuesForm(
+            project=project,
+            tag=tag,
+            data=request.POST or None,
+            prefix='tag-%s' % (tag,),
+            initial={
+                'values': ', '.join(initial.get(tag, [])),
+            },
+        ))
+
+    if request.method == 'POST' and all(f.is_valid() for f in tag_forms):
+        tags = {}
+        for form in tag_forms:
+            values = form.cleaned_data['values']
+            if values:
+                tags[form.tag] = values
+        project.update_option('notifcation:tags', tags)
+
+        messages.add_message(request, messages.SUCCESS,
+            _('Your settings were saved successfully.'))
+
+        return HttpResponseRedirect(reverse('sentry-project-notifications', args=[project.team.slug, project.slug]))
+
+    context = csrf(request)
+    context.update({
+        'team': team,
+        'project': project,
+        'tag_forms': tag_forms,
+        'page': 'notifications',
+        'SECTION': 'team',
+        'SUBSECTION': 'projects',
+    })
+    return render_to_response('sentry/projects/notifications.html', context, request)
+
+
 @has_access(MEMBER_OWNER)
 @csrf_protect
 def manage_plugins(request, team, project):
