@@ -6,6 +6,7 @@ sentry.web.frontend.teams
 :license: BSD, see LICENSE for more details.
 """
 from django.contrib import messages
+from django.contrib.auth.models import User
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
@@ -13,17 +14,28 @@ from django.views.decorators.csrf import csrf_protect
 from django.utils.translation import ugettext as _
 
 from sentry.constants import MEMBER_USER, MEMBER_OWNER
-from sentry.models import PendingTeamMember, TeamMember
-from sentry.permissions import can_add_team_member, can_remove_team, can_create_projects, \
-  can_create_teams, can_edit_team_member, can_remove_team_member
+from sentry.models import PendingTeamMember, TeamMember, AccessGroup
+from sentry.permissions import (can_add_team_member, can_remove_team, can_create_projects,
+    can_create_teams, can_edit_team_member, can_remove_team_member)
 from sentry.plugins import plugins
 from sentry.web.decorators import login_required, has_access
-from sentry.web.forms.teams import NewTeamForm, NewTeamAdminForm, \
-  EditTeamForm, EditTeamAdminForm, EditTeamMemberForm, NewTeamMemberForm, \
-  InviteTeamMemberForm, RemoveTeamForm, AcceptInviteForm
+from sentry.web.forms.teams import (NewTeamForm, NewTeamAdminForm,
+    EditTeamForm, EditTeamAdminForm, EditTeamMemberForm, NewTeamMemberForm,
+    InviteTeamMemberForm, RemoveTeamForm, AcceptInviteForm, NewAccessGroupForm,
+    EditAccessGroupForm, NewAccessGroupMemberForm, NewAccessGroupProjectForm,
+    RemoveAccessGroupForm)
 from sentry.web.helpers import render_to_response
 
 
+def render_with_team_context(team, template, context, request=None):
+    context.update({
+        'team': team,
+        'SECTION': 'team',
+    })
+
+    return render_to_response(template, context, request)
+
+
 @login_required
 def team_list(request):
     return render_to_response('sentry/teams/list.html', {}, request)
@@ -98,12 +110,35 @@ def manage_team(request, team):
         'can_remove_team': can_remove_team(request.user, team),
         'page': 'details',
         'form': form,
-        'team': team,
-        'SECTION': 'team',
         'SUBSECTION': 'settings',
     })
 
-    return render_to_response('sentry/teams/manage.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/manage.html', context, request)
+
+
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def remove_team(request, team):
+    if not can_remove_team(request.user, team):
+        return HttpResponseRedirect(reverse('sentry'))
+
+    if request.method == 'POST':
+        form = RemoveTeamForm(request.POST)
+    else:
+        form = RemoveTeamForm()
+
+    if form.is_valid():
+        team.delete()
+        return HttpResponseRedirect(reverse('sentry-team-list'))
+
+    context = csrf(request)
+    context.update({
+        'page': 'settings',
+        'form': form,
+        'SUBSECTION': 'settings',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/remove.html', context, request)
 
 
 @has_access(MEMBER_OWNER)
@@ -117,15 +152,13 @@ def manage_team_projects(request, team):
 
     context = csrf(request)
     context.update({
-        'can_add_project': can_create_projects(request.user, team),
         'page': 'projects',
         'team': team,
         'project_list': project_list,
-        'SECTION': 'team',
         'SUBSECTION': 'projects',
     })
 
-    return render_to_response('sentry/teams/projects/index.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/projects/index.html', context, request)
 
 
 @has_access(MEMBER_OWNER)
@@ -140,47 +173,19 @@ def manage_team_members(request, team):
 
     context = csrf(request)
     context.update({
-        'can_add_member': can_add_team_member(request.user, team),
         'page': 'members',
-        'team': team,
         'member_list': member_list,
         'pending_member_list': pending_member_list,
-        'SECTION': 'team',
         'SUBSECTION': 'members',
     })
 
-    return render_to_response('sentry/teams/members/index.html', context, request)
-
-
-@has_access(MEMBER_OWNER)
-@csrf_protect
-def remove_team(request, team):
-    if not can_remove_team(request.user, team):
-        return HttpResponseRedirect(reverse('sentry'))
-
-    form = RemoveTeamForm(request.POST or None)
-
-    if form.is_valid():
-        team.delete()
-        return HttpResponseRedirect(reverse('sentry-team-list'))
-
-    context = csrf(request)
-    context.update({
-        'page': 'settings',
-        'form': form,
-        'team': team,
-        'SECTION': 'team',
-        'SUBSECTION': 'settings',
-    })
-
-    return render_to_response('sentry/teams/remove.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/members/index.html', context, request)
 
 
 @csrf_protect
 @has_access(MEMBER_OWNER)
 def new_team_member(request, team):
-    can_add_member = can_add_team_member(request.user, team)
-    if not can_add_member:
+    if not can_add_team_member(request.user, team):
         return HttpResponseRedirect(reverse('sentry'))
 
     initial = {
@@ -215,14 +220,12 @@ def new_team_member(request, team):
     context = csrf(request)
     context.update({
         'page': 'members',
-        'team': team,
         'add_form': add_form,
         'invite_form': invite_form,
-        'SECTION': 'team',
         'SUBSECTION': 'members',
     })
 
-    return render_to_response('sentry/teams/members/new.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/members/new.html', context, request)
 
 
 @csrf_protect
@@ -301,13 +304,11 @@ def edit_team_member(request, team, member_id):
     context.update({
         'page': 'members',
         'member': member,
-        'team': team,
         'form': form,
-        'SECTION': 'team',
         'SUBSECTION': 'members',
     })
 
-    return render_to_response('sentry/teams/members/edit.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/members/edit.html', context, request)
 
 
 @csrf_protect
@@ -333,12 +334,10 @@ def remove_team_member(request, team, member_id):
     context.update({
         'page': 'members',
         'member': member,
-        'team': team,
-        'SECTION': 'team',
         'SUBSECTION': 'members',
     })
 
-    return render_to_response('sentry/teams/members/remove.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/members/remove.html', context, request)
 
 
 @csrf_protect
@@ -459,10 +458,195 @@ def create_new_team_project(request, team):
     context = csrf(request)
     context.update({
         'form': form,
-        'team': team,
         'page': 'projects',
-        'SECTION': 'team',
         'SUBSECTION': 'new_project',
     })
 
-    return render_to_response('sentry/teams/projects/new.html', context, request)
+    return render_with_team_context(team, 'sentry/teams/projects/new.html', context, request)
+
+
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def manage_access_groups(request, team):
+    context = csrf(request)
+    context.update({
+        'can_add_group': True,
+        'group_list': AccessGroup.objects.filter(team=team),
+        'SUBSECTION': 'groups',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/groups/list.html', context, request)
+
+
+@csrf_protect
+@has_access(MEMBER_OWNER)
+def new_access_group(request, team):
+    initial = {
+        'type': MEMBER_USER,
+    }
+
+    form = NewAccessGroupForm(request.POST or None, initial=initial)
+    if form.is_valid():
+        inst = form.save(commit=False)
+        inst.team = team
+        inst.managed = False
+        inst.save()
+        return HttpResponseRedirect(reverse('sentry-manage-access-groups', args=[team.slug]))
+
+    context = csrf(request)
+    context.update({
+        'form': form,
+        'SUBSECTION': 'groups',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/groups/new.html', context, request)
+
+
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def access_group_details(request, team, group_id):
+    try:
+        group = AccessGroup.objects.get(team=team, id=group_id)
+    except AccessGroup.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-manage-access-groups', args=[team.slug]))
+
+    form = EditAccessGroupForm(request.POST or None, instance=group)
+    if form.is_valid():
+        form.save()
+
+    context = csrf(request)
+    context.update({
+        'group': group,
+        'form': form,
+        'group_list': AccessGroup.objects.filter(team=team),
+        'page': 'details',
+        'SUBSECTION': 'groups',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/groups/details.html', context, request)
+
+
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def remove_access_group(request, team, group_id):
+    try:
+        group = AccessGroup.objects.get(team=team, id=group_id)
+    except AccessGroup.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-manage-access-groups', args=[team.slug]))
+
+    if request.method == 'POST':
+        form = RemoveAccessGroupForm(request.POST)
+    else:
+        form = RemoveAccessGroupForm()
+
+    if form.is_valid():
+        group.delete()
+
+        messages.add_message(request, messages.SUCCESS,
+            _('%s was permanently removed.') % (group.name,))
+
+        return HttpResponseRedirect(reverse('sentry-manage-access-groups', args=[team.slug]))
+
+    context = csrf(request)
+    context.update({
+        'form': form,
+        'group': group,
+        'page': 'details',
+        'SUBSECTION': 'groups',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/groups/remove.html', context, request)
+
+
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def access_group_members(request, team, group_id):
+    try:
+        group = AccessGroup.objects.get(team=team, id=group_id)
+    except AccessGroup.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-manage-access-groups', args=[team.slug]))
+
+    form = NewAccessGroupMemberForm(request.POST or None)
+    if form.is_valid():
+        user = form.cleaned_data['user']
+        group.members.add(user)
+
+        messages.add_message(request, messages.SUCCESS,
+            _('%s was added to this access group.') % (user.email,))
+
+        return HttpResponseRedirect(reverse('sentry-access-group-members', args=[team.slug, group.id]))
+
+    context = csrf(request)
+    context.update({
+        'group': group,
+        'form': form,
+        'member_list': group.members.all(),
+        'group_list': AccessGroup.objects.filter(team=team),
+        'page': 'members',
+        'SUBSECTION': 'groups',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/groups/members.html', context, request)
+
+
+@csrf_protect
+@has_access(MEMBER_OWNER)
+def remove_access_group_member(request, team, group_id, user_id):
+    try:
+        group = AccessGroup.objects.get(team=team, id=group_id)
+    except AccessGroup.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-access-group-members', args=[team.slug, group.id]))
+
+    try:
+        user = User.objects.get(id=user_id)
+    except User.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-access-group-members', args=[team.slug, group.id]))
+
+    group.members.remove(user)
+
+    return HttpResponseRedirect(reverse('sentry-access-group-members', args=[team.slug, group.id]))
+
+
+@has_access(MEMBER_OWNER)
+@csrf_protect
+def access_group_projects(request, team, group_id):
+    try:
+        group = AccessGroup.objects.get(team=team, id=group_id)
+    except AccessGroup.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-manage-access-groups', args=[team.slug]))
+
+    form = NewAccessGroupProjectForm(group, request.POST or None)
+    if form.is_valid():
+        project = form.cleaned_data['project']
+        group.projects.add(project)
+
+        messages.add_message(request, messages.SUCCESS,
+            _('%s was added to this access group.') % (project.name,))
+
+        return HttpResponseRedirect(reverse('sentry-access-group-projects', args=[team.slug, group.id]))
+
+    context = csrf(request)
+    context.update({
+        'group': group,
+        'form': form,
+        'project_list': group.projects.all(),
+        'group_list': AccessGroup.objects.filter(team=team),
+        'page': 'projects',
+        'SUBSECTION': 'groups',
+    })
+
+    return render_with_team_context(team, 'sentry/teams/groups/projects.html', context, request)
+
+
+@csrf_protect
+@has_access(MEMBER_OWNER)
+# XXX: has_access is automatically converting project for us
+def remove_access_group_project(request, team, group_id, project):
+    try:
+        group = AccessGroup.objects.get(team=team, id=group_id)
+    except AccessGroup.DoesNotExist:
+        return HttpResponseRedirect(reverse('sentry-access-group-projects', args=[team.slug, group.id]))
+
+    group.projects.remove(project)
+
+    return HttpResponseRedirect(reverse('sentry-access-group-projects', args=[team.slug, group.id]))
