@@ -2,7 +2,7 @@
 sentry.web.views
 ~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
@@ -24,26 +24,10 @@ from sentry.permissions import can_create_projects, can_create_teams
 logger = logging.getLogger('sentry.errors')
 
 
-def get_project_list(user=None, access=None, hidden=False, key='id'):
-    """
-    Returns a SortedDict of all projects a user has some level of access to.
-    """
-    if not (user and user.is_authenticated()):
-        return SortedDict()
-
-    base_qs = Project.objects
-    if not hidden:
-        base_qs = base_qs.filter(status=0)
-
-    if not settings.PUBLIC:
-        # If the user is authenticated, include their memberships
-        teams = Team.objects.get_for_user(user, access).values()
-        if not teams:
-            return SortedDict()
-        base_qs = base_qs.filter(team__in=teams)
-
+def get_project_list(user=None, access=None, hidden=False, key='id', team=None):
+    warnings.warn('get_project_list is Deprecated. Use Project.objects.get_for_user instead.', DeprecationWarning)
     return SortedDict((getattr(p, key), p)
-        for p in base_qs.order_by('name'))
+            for p in Project.objects.get_for_user(user, access))
 
 
 def group_is_public(group, user):
@@ -95,13 +79,6 @@ def get_login_url(reset=False):
     return _LOGIN_URL
 
 
-def iter_data(obj):
-    for k, v in obj.data.iteritems():
-        if k.startswith('_') or k in ['url']:
-            continue
-        yield k, v
-
-
 def get_internal_project():
     try:
         project = Project.objects.get(id=settings.PROJECT)
@@ -124,29 +101,25 @@ def get_default_context(request, existing_context=None, team=None):
     context = {
         'HAS_SEARCH': settings.USE_SEARCH,
         'MESSAGES_PER_PAGE': settings.MESSAGES_PER_PAGE,
-        'INTERNAL_PROJECT': get_internal_project(),
-        'PROJECT_ID': str(settings.PROJECT),
         'URL_PREFIX': settings.URL_PREFIX,
         'PLUGINS': plugins,
-        'USE_JS_CLIENT': settings.USE_JS_CLIENT,
     }
 
     if request:
         context.update({
             'request': request,
-            'can_create_projects': can_create_projects(request.user),
             'can_create_teams': can_create_teams(request.user),
         })
         if team:
             context.update({
-                'can_admin_team': Team.objects.get_for_user(request.user, MEMBER_OWNER)
+                'can_admin_team': Team.objects.get_for_user(request.user, MEMBER_OWNER),
+                'can_create_projects': can_create_projects(request.user, team=team),
             })
+        else:
+            context['can_create_projects'] = can_create_projects(request.user)
 
         if not existing_context or 'PROJECT_LIST' not in existing_context:
-            if team:
-                project_list = Project.objects.filter(team=team)
-            else:
-                project_list = get_project_list(request.user).values()
+            project_list = Project.objects.get_for_user(request.user, team=team)
             context['PROJECT_LIST'] = sorted(project_list, key=lambda x: x.name)
         if not existing_context or 'TEAM_LIST' not in existing_context:
             context['TEAM_LIST'] = sorted(Team.objects.get_for_user(request.user).values(), key=lambda x: x.name)
